@@ -25,6 +25,7 @@
 #include "spvm_use.h"
 #include "spvm_op_checker.h"
 #include "spvm_opcode_builder.h"
+#include "spvm_object.h"
 
 SPVM_COMPILER* SPVM_COMPILER_new() {
   SPVM_COMPILER* compiler = SPVM_UTIL_ALLOCATOR_safe_malloc_zero(sizeof(SPVM_COMPILER));
@@ -66,6 +67,32 @@ SPVM_COMPILER* SPVM_COMPILER_new() {
   return compiler;
 }
 
+SPVM_RUNTIME* SPVM_COMPILER_new_runtime(SPVM_COMPILER* compiler) {
+  
+  SPVM_RUNTIME* runtime = SPVM_UTIL_ALLOCATOR_safe_malloc_zero(sizeof(SPVM_RUNTIME));
+  
+  SPVM_ENV* env = (SPVM_ENV*)SPVM_RUNTIME_API_get_env_runtime();
+  
+  runtime->env = env;
+
+  runtime->compiler = compiler;
+  
+  // Set global runtime
+  SPVM_RUNTIME_API_set_runtime(env, runtime);
+  
+  // Initialize Package Variables
+  runtime->package_var_accesss = SPVM_UTIL_ALLOCATOR_safe_malloc_zero(sizeof(SPVM_VALUE) * (compiler->op_package_vars->length + 1));
+
+  // Arguments
+  runtime->args = SPVM_UTIL_ALLOCATOR_safe_malloc_zero(sizeof(SPVM_VALUE) * 255);
+
+  runtime->mortal_stack_capacity = 1;
+
+  runtime->mortal_stack = SPVM_UTIL_ALLOCATOR_safe_malloc_zero(sizeof(SPVM_OBJECT*) * runtime->mortal_stack_capacity);
+  
+  return runtime;
+}
+
 void SPVM_COMPILER_add_basic_types(SPVM_COMPILER* compiler) {
   // Add unknown basic_type
   {
