@@ -1,6 +1,6 @@
 #ifndef SPVM_GLOBAL_H
 #define SPVM_GLOBAL_H
 
-SPVM_RUNTIME* SPVM_GLOBAL_RUNTIME;
+static SPVM_RUNTIME* SPVM_GLOBAL_RUNTIME;
 
 #endif
