@@ -53,6 +53,12 @@ struct SPVM_runtime {
   
   SPVM_VALUE* args;
   
+  SPVM_OBJECT** mortal_stack;
+  
+  int32_t mortal_stack_top;
+  
+  int32_t mortal_stack_capacity;
+
   int32_t objects_count;
 };
 
