@@ -4,7 +4,7 @@
 #include "spvm_base.h"
 
 struct SPVM_use {
-  const char* package_name;
+  SPVM_OP* op_type;
 };
 
 SPVM_USE* SPVM_USE_new(SPVM_COMPILER* compiler);
